==========
pseudonaja
==========


.. image:: https://img.shields.io/pypi/v/pseudonaja.svg
        :target: https://pypi.python.org/pypi/pseudonaja

.. image:: https://img.shields.io/travis/dsoon/pseudonaja.svg
        :target: https://travis-ci.com/dsoon/pseudonaja

.. image:: https://readthedocs.org/projects/pseudonaja/badge/?version=latest
        :target: https://pseudonaja.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Pseudocode interpreter


* Free software: MIT license
* Documentation: https://pseudonaja.readthedocs.io.


Features
--------

* TODO

Credits
-------

Lexer and Parser - Sly_

.. _Sly: https://github.com/dabeaz/sly


This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
